# Changelog

## [v0.1.2](https://github.com/kai2nenobu/convert-teams-wiki/compare/v0.1.1...v0.1.2) - 2024-03-16
### Features
- feat: add `<h2>` tag handling by @kai2nenobu in https://github.com/kai2nenobu/convert-teams-wiki/pull/7
- feat: add `--version` option by @kai2nenobu in https://github.com/kai2nenobu/convert-teams-wiki/pull/9
- chore: add a configuration for Dependabot by @kai2nenobu in https://github.com/kai2nenobu/convert-teams-wiki/pull/10
- chore: fix a wrong version number by @kai2nenobu in https://github.com/kai2nenobu/convert-teams-wiki/pull/11

## [v0.1.1](https://github.com/kai2nenobu/convert-teams-wiki/compare/v0.1.0...v0.1.1) - 2024-03-13
- feat: add --verbose option to output logging message by @kai2nenobu in https://github.com/kai2nenobu/convert-teams-wiki/pull/5

## [v0.1.0](https://github.com/kai2nenobu/convert-teams-wiki/compare/v0.0.1...v0.1.0) - 2024-03-13
- First implementation by @kai2nenobu in https://github.com/kai2nenobu/convert-teams-wiki/pull/2
- Add a release workflow by @kai2nenobu in https://github.com/kai2nenobu/convert-teams-wiki/pull/4

## [v0.0.1](https://github.com/kai2nenobu/convert-teams-wiki/commits/v0.0.1) - 2024-03-13

- Initialize a project
